=====================
Tutorials on models
=====================

The following tutorials can also be found in
`zfit tutorials as Jupyter Notebooks. <https://github.com/zfit/zfit-tutorials>`_

.. toctree::
    :maxdepth: 1

    ../../_tmp/zfit-tutorials/components/20 - Composite Models.ipynb
    ../../_tmp/zfit-tutorials/components/50 - Custom code and run mode.ipynb
    ../../_tmp/zfit-tutorials/components/60 - Custom PDF.ipynb
    ../../_tmp/zfit-tutorials/components/62 - Multidim Custom PDF.ipynb
    ../../_tmp/zfit-tutorials/components/80 Toy Study.ipynb
